﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart.Drawing;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Text = "Bar 클래스 : MultiBar 속성을 사용해 바 레이아웃 설정하기";

            #region 레이아웃 콤보 박스를 설정한다.

            this.layoutComboBox.DropDownStyle = ComboBoxStyle.DropDownList;

            this.layoutComboBox.Items.Add(MultiBars.None      );
            this.layoutComboBox.Items.Add(MultiBars.Side      );
            this.layoutComboBox.Items.Add(MultiBars.Stacked   );
            this.layoutComboBox.Items.Add(MultiBars.Stacked100);
            this.layoutComboBox.Items.Add(MultiBars.SideAll   );

            this.layoutComboBox.SelectedIndex = 1;

            #endregion
            #region 티차트를 설정한다.

            this.tChart.Panel.Pen = new ChartPen(Color.Black);

            for(int i = 0; i < 3; i++)
            {
                Bar bar = new Bar();

                bar.FillSampleValues(6);

                this.tChart.Series.Add(bar);
            }

            #endregion

            this.layoutComboBox.SelectedIndexChanged += layoutComboBox_SelectedIndexChanged;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 레이아웃 콤보 박스 선택 인덱스 변경시 처리하기 - layoutComboBox_SelectedIndexChanged(sender, e)

        /// <summary>
        /// 레이아웃 콤보 박스 선택 인덱스 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void layoutComboBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            MultiBars multiBars = (MultiBars)this.layoutComboBox.SelectedItem;

            foreach(Bar bar in this.tChart.Series)
            {
                bar.MultiBar = multiBars;
            }

            if(multiBars == MultiBars.SelfStack)
            {
                foreach(Bar bar in this.tChart.Series)
                {
                    bar.BarWidthPercent = 40;
                }
            }

            bool markerVisible =
            (
                multiBars != MultiBars.SelfStack &&
                multiBars != MultiBars.Stacked   &&
                multiBars != MultiBars.Stacked100
            );

            foreach(Bar bar in this.tChart.Series)
            {
                bar.Marks.Visible = markerVisible;
            }
        }

        #endregion
    }
}